@@ -179,7 +179,7 @@ int parse_sleep_config(SleepConfig **ret_sleep_config) {
         dbg_cnt = -1;
         while (sc->states[SLEEP_HYBRID_SLEEP] && sc->states[SLEEP_HYBRID_SLEEP][++dbg_cnt])
                 log_debug_elogind("states[SLEEP_HYBRID_SLEEP][%d] = %s", dbg_cnt, sc->states[SLEEP_HYBRID_SLEEP][dbg_cnt]);
-        log_debug_elogind("hibernate_delay_usec: %lu seconds (%lu minutes)",
+        log_debug_elogind("hibernate_delay_usec: %" PRIu64 " seconds (%lu minutes)",
                           sc->hibernate_delay_usec / USEC_PER_SEC, sc->hibernate_delay_usec / USEC_PER_MINUTE);
 #endif // ENABLE_DEBUG_ELOGIND
 
@@ -593,6 +593,7 @@ int get_total_suspend_interval(Hashmap *last_capacity, usec_t *ret) {
 int battery_trip_point_alarm_exists(void) {
         _cleanup_(sd_device_enumerator_unrefp) sd_device_enumerator *e = NULL;
         sd_device *dev;
+        bool has_battery = false;
         int r;
 
         r = battery_enumerator_new(&e);
@@ -600,21 +601,25 @@ int battery_trip_point_alarm_exists(void) {
                 return log_debug_errno(r, "Failed to initialize battery enumerator: %m");
 
         FOREACH_DEVICE(e, dev) {
-                int battery_alarm;
-                const char *s;
+                const char *alarm_attr;
+                int has_alarm;
 
-                r = sd_device_get_sysattr_value(dev, "alarm", &s);
-                if (r < 0)
-                        return log_device_debug_errno(dev, r, "Failed to read battery alarm: %m");
+                has_battery = true;
 
-                r = safe_atoi(s, &battery_alarm);
+                r = sd_device_get_sysattr_value(dev, "alarm", &alarm_attr);
                 if (r < 0)
-                        return log_device_debug_errno(dev, r, "Failed to parse battery alarm: %m");
-                if (battery_alarm <= 0)
+                        return log_device_debug_errno(dev, r, "Failed to read battery alarm attribute: %m");
+
+                r = safe_atoi(alarm_attr, &has_alarm);
+                if (r < 0)
+                        return log_device_debug_errno(dev, r,
+                                                      "Failed to parse battery alarm attribute '%s': %m",
+                                                      alarm_attr);
+                if (has_alarm <= 0)
                         return false;
         }
 
-        return true;
+        return has_battery;
 }
 
 /* Return true if wakeup type is APM timer */
