@@ -127,18 +127,6 @@ void test_setup_logging(int level) {
         log_open();
 }
 
-int log_tests_skipped(const char *message) {
-        log_notice("%s: %s, skipping tests.",
-                   program_invocation_short_name, message);
-        return EXIT_TEST_SKIP;
-}
-
-int log_tests_skipped_errno(int r, const char *message) {
-        log_notice_errno(r, "%s: %s, skipping tests: %m",
-                         program_invocation_short_name, message);
-        return EXIT_TEST_SKIP;
-}
-
 int write_tmpfile(char *pattern, const char *contents) {
         _cleanup_close_ int fd = -1;
 
