@@ -46,7 +46,11 @@ TEST(cg_create) {
         int r;
 
         r = cg_unified_cached(false);
+#if 0 /// If elogind is built in a minimal container, cg_unified_cached() might return -ENOENT.
         if (r == -ENOMEDIUM) {
+#else // 0
+        if (r == -ENOMEDIUM || r == -ENOENT) {
+#endif // 0
                 log_tests_skipped("cgroup not mounted");
                 return;
         }
@@ -63,6 +67,10 @@ TEST(cg_create) {
 
         log_info("Paths for test:\n%s\n%s", test_a, test_b);
 
+        /* Possibly clean up left-overs from aboted previous runs */
+        (void) cg_trim(SYSTEMD_CGROUP_CONTROLLER, test_a, /* delete_root= */ true);
+        (void) cg_trim(SYSTEMD_CGROUP_CONTROLLER, test_b, /* delete_root= */ true);
+
         r = cg_create(SYSTEMD_CGROUP_CONTROLLER, test_a);
         if (IN_SET(r, -EPERM, -EACCES, -EROFS)) {
                 log_info_errno(r, "Skipping %s: %m", __func__);
